@@ -10,19 +10,23 @@ from mock.mock import Mock, patch
 from core_composer_app.components.type import api as type_api
 from core_composer_app.components.type.models import Type
 from core_main_app.commons import exceptions
+from core_main_app.utils.tests_tools.MockUser import create_mock_user
+from core_main_app.utils.tests_tools.RequestMock import create_mock_request
 
 
 class TestTypeGet(TestCase):
     @patch.object(Type, "get_by_id")
     def test_type_get_returns_type(self, mock_get_by_id):
         # Arrange
+        mock_user = create_mock_user("1", is_superuser=True)
+        mock_request = create_mock_request(user=mock_user)
         type_filename = "Schema"
         mock_type = _create_mock_type(type_filename)
 
         mock_get_by_id.return_value = mock_type
 
         # Act
-        result = type_api.get(mock_type.id)
+        result = type_api.get(mock_type.id, request=mock_request)
 
         # Assert
         self.assertIsInstance(result, Type)
@@ -32,25 +36,29 @@ class TestTypeGet(TestCase):
         self, mock_get_by_id
     ):
         # Arrange
+        mock_user = create_mock_user("1", is_superuser=True)
+        mock_request = create_mock_request(user=mock_user)
         mock_absent_id = ObjectId()
         mock_get_by_id.side_effect = exceptions.DoesNotExist("")
 
         # Act + Assert
         with self.assertRaises(exceptions.DoesNotExist):
-            type_api.get(mock_absent_id)
+            type_api.get(mock_absent_id, request=mock_request)
 
 
 class TestTypeGetAll(TestCase):
     @patch.object(Type, "get_all")
     def test_get_all_types_returns_types(self, mock_get_all):
         # Arrange
+        mock_user = create_mock_user("1", is_superuser=True)
+        mock_request = create_mock_request(user=mock_user)
         mock_type1 = _create_mock_type()
         mock_type2 = _create_mock_type()
 
         mock_get_all.return_value = [mock_type1, mock_type2]
 
         # Act
-        result = type_api.get_all()
+        result = type_api.get_all(request=mock_request)
 
         # Assert
         self.assertTrue(all(isinstance(item, Type) for item in result))
@@ -60,13 +68,15 @@ class TestTypeGetAllComplexType(TestCase):
     @patch.object(Type, "get_all_complex_type")
     def test_get_all_types_returns_types(self, mock_get_all_complex_type):
         # Arrange
+        mock_user = create_mock_user("1", is_superuser=True)
+        mock_request = create_mock_request(user=mock_user)
         mock_type1 = _create_mock_type()
         mock_type2 = _create_mock_type()
 
         mock_get_all_complex_type.return_value = [mock_type1, mock_type2]
 
         # Act
-        result = type_api.get_all_complex_type()
+        result = type_api.get_all_complex_type(request=mock_request)
 
         # Assert
         self.assertTrue(all(isinstance(item, Type) for item in result))
@@ -76,26 +86,32 @@ class TestTypeUpsert(TestCase):
     @override_settings(ROOT_URLCONF="core_main_app.urls")
     @patch.object(Type, "save")
     def test_type_upsert_valid_returns_type(self, mock_save):
+        mock_user = create_mock_user("1", is_superuser=True)
+        mock_request = create_mock_request(user=mock_user)
         type_object = _create_type()
 
         mock_save.return_value = type_object
-        result = type_api.upsert(type_object)
+        result = type_api.upsert(type_object, request=mock_request)
         self.assertIsInstance(result, Type)
 
     @override_settings(ROOT_URLCONF="core_main_app.urls")
     @patch.object(Type, "save")
     def test_type_upsert_invalid_filename_raises_validation_error(self, mock_save):
+        mock_user = create_mock_user("1", is_superuser=True)
+        mock_request = create_mock_request(user=mock_user)
         type_object = _create_type(filename=1)
         mock_save.side_effect = django_exceptions.ValidationError("")
         with self.assertRaises(django_exceptions.ValidationError):
-            type_api.upsert(type_object)
+            type_api.upsert(type_object, request=mock_request)
 
     @patch.object(Type, "save")
     def test_type_upsert_invalid_core_type_raises_core_error(self, mock_save):
+        mock_user = create_mock_user("1", is_superuser=True)
+        mock_request = create_mock_request(user=mock_user)
         type_object = _create_type(content="<schema></schema>")
         mock_save.return_value = None
         with self.assertRaises(exceptions.CoreError):
-            type_api.upsert(type_object)
+            type_api.upsert(type_object, request=mock_request)
 
 
 def _create_mock_type(filename="", content=""):
